#########################################################
# "Who Opposes Climate Regulation? Business Preferences 
# for the European Emission Trading Scheme"
# Federica Genovese & Endre Tvinnereim
# 02/05/18 (Run by ET/FG)
# R version: 3.4.3
# stm version: 1.1.3
#########################################################

# Structural topic modeling of open-ended survey responses from the Carbon Market Survey (Thomson Reuters Point Carbon)
# Background: http://structuraltopicmodel.com/ ; _vignette_ "stm: R Package for Structural Topic Models"

########################
library(devtools)
library(R.methodsS3)
library(stm)
library(SnowballC)
library(foreign)

# Clear all
rm(list=ls(all=TRUE))

# read in data
#setwd("O:/2.7-ETS-bears/2.ETS-preferences/data/text")
setwd("/Users/genovesefederica/Dropbox/ETS_opinionconsultation/rep_GenoveseTvinnereim_rio/Data/textdata")

data07 <- read.csv("cms_text_2007.csv", sep=";")
data08 <- read.csv("cms_text_2008.csv", sep=";")
data09 <- read.csv("cms_text_2009.csv", sep=";")
data10 <- read.csv("cms_text_2010.csv", sep=";")
data11 <- read.csv("cms_text_2011.csv", sep=";")
data12 <- read.csv("cms_text_2012.csv", sep=";")
data13 <- read.csv("cms_text_2013.csv", sep=";")

alldata <- rbind(data07, data08, data09, data10, data11, data12, data13)

table(alldata$year)
table(alldata$costeff)
table(alldata$mature)

# Make the open answers text not factor 
alldata$text <- as.character(alldata$text)
# rawdata$ETS <- NULL  # because it's NA

rm(data07, data08, data09, data10, data11, data12, data13)

# End of merging

# Pre-processing and recoding
# Recode variables 
table(alldata$year, alldata$emissions)
# Zeroes are in fact missing. See codebook. 
# Make missing into one factor observations; others are high or low
options <- c("high", "low", "missing")
# Emission level
alldata$emis2 <- "missing"
alldata$emis2 <- as.factor(alldata$emis2)
levels(alldata$emis2) <- options
table(alldata$emissions)
# Article: "Firm: high CO2 emitter that takes the value of 0 if the grouped companies
# selected a category below 1 million tonnes, and 1 for anything above that threshold."

# From codebook: 
# 1	Less than 500,000 tonnes
# 2	500,000 - 1 million tonnes
# 3	1 million - 5 million tonnes
# 4	5 million - 10 million tonnes
# 5	More than 10 million tonnes
# 6	No emissions
# 7	Don't know

alldata$emis2[alldata$emissions==1 | alldata$emissions==2] <- "low"
alldata$emis2[alldata$emissions==3 | alldata$emissions==4 | alldata$emissions==5] <- "high"
alldata$emis2[alldata$emissions==0 | alldata$emissions==6 |
              alldata$emissions==7 | alldata$emissions== -111] <- "missing"
with(alldata, table(emissions, emis2))
with(alldata, table(emissions, year))

# Something seems wrong about 2014 and codebook doesn't help; 2015 doesn't have the data. 
alldata$emis2[alldata$year>2013] <- "missing" 
with(alldata, table(emis2, year))
alldata$emissions <- NULL

# # Question wording: In 2007-13, participants were asked to provide any comments right after being asked about the maturity and cost-effectiveness of the EU ETS. (In 2014-15, they were asked more generally to evaluate cap-and-trade as a climate policy tool in a separate part of the survey, using the question "Please share your view on cap-and-trade as a policy instrument for emission abatement.") 
# wordings <- c("specific", "general")
# alldata$wording <- "specific"
# alldata$wording <- as.factor(alldata$wording)
# levels(alldata$wording) <- wordings
# alldata$wording[alldata$year>2013] <- "general"
# with(alldata, table(year, wording))

# remove missing data
alldata <- na.omit(alldata) # thanks to http://www.statmethods.net/input/missingdata.html
# rm(rawdata)
# save(alldata, file="alldata-2018.Rdata")

# Summary statistics
table(alldata$ETS)
table(alldata$ETS, alldata$emis2)

#######################
# Text analysis start
# load("alldata-2018.Rdata")
#stemming/stopword removal, etc.
processed <- textProcessor(alldata$text, metadata=alldata, language="en", verbose=TRUE)

#structure and index for usage in the stm model. Verify no-missingness.
out <- prepDocuments(processed$documents, processed$vocab, processed$meta,
                     lower.thresh=3)
#output will have object meta, documents, and vocab
#docs <- out$documents
#vocab <- out$vocab
#meta <-out$meta

# save workspace before model runs
# 'alldata' has the underlying data; 'out' has the data for the STM model
# save(alldata, out, file = "preparedData-2018-carbonmarket-before-stm-final.RData")

###########
# RUN STM #
###########
load("preparedData-2018-carbonmarket-before-stm-final.Rdata")
str(out$meta) # for list of variables to include in the prevalence vector

ets10 <- stm(out$documents,
             out$vocab,
             K=10,
             init.type="Spectral",
             prevalence =~ year + ETS + emis2,             
             max.em.its=500, 
             data=out$meta)

# Save objects (data and STM object) after model runs
#save(out, ets10, file = "preparedModels-2018-ets10-stm-final.RData")

####
# Analysis on chosen model run 
# Most frequent and exclusive terms (FREX): 

load("preparedModels-2018-ets10-stm-final.RData")

# counts
with(out$meta, table(year, ETS))
table(out$meta$ETS)

k <- 10
etsPrevFit <- ets10
labelTopics(etsPrevFit, topics=NULL, n=10)[2]

# Responses that are highly associated with topics
findThoughts(etsPrevFit, texts=out$meta$text, n=10, topics=1)$docs[[1]]        # 
findThoughts(etsPrevFit, texts=out$meta$text, n=10, topics=2)$docs[[1]] # allocation issues
findThoughts(etsPrevFit, texts=out$meta$text, n=10, topics=3)$docs[[1]]   
findThoughts(etsPrevFit, texts=out$meta$text, n=10, topics=4)$docs[[1]] # 
findThoughts(etsPrevFit, texts=out$meta$text, n=10, topics=5)$docs[[1]] # 
findThoughts(etsPrevFit, texts=out$meta$text, n=10, topics=6)$docs[[1]]
findThoughts(etsPrevFit, texts=out$meta$text, n=10, topics=7)$docs[[1]]
findThoughts(etsPrevFit, texts=out$meta$text, n=10, topics=8)$docs[[1]] # theory vs. practice
findThoughts(etsPrevFit, texts=out$meta$text, n=10, topics=9)$docs[[1]] # too early to tell
findThoughts(etsPrevFit, texts=out$meta$text, n=10, topics=10)$docs[[1]] # regulatory/political uncertainty

# Table A.18: most representative responses/sentences
labelTopics(etsPrevFit, topics=c(2,8,9,10), n=6)[2]
findThoughts(etsPrevFit, texts=out$meta$text, n=5, topics=2)$docs[[1]] # allocation issues
findThoughts(etsPrevFit, texts=out$meta$text, n=5, topics=8)$docs[[1]] # theory vs. practice
findThoughts(etsPrevFit, texts=out$meta$text, n=5, topics=9)$docs[[1]] # too early to tell
findThoughts(etsPrevFit, texts=out$meta$text, n=5, topics=10)$docs[[1]] # regulatory/political uncertainty



# Figures: topic prevalence over co-variates
prep <- estimateEffect(1:10 ~ year+ETS+emis2, 
                       etsPrevFit,
                       meta=out$meta, 
                       uncertainty = "Global")

prep <- estimateEffect(1:10 ~ year+ETS+emis2, 
                       etsPrevFit,
                       meta=out$meta, 
                       uncertainty = "Global")


topicselect <- c(2,8,9,10)
topiclabels <- c("allocation issues",
                 "theory vs. practice",
                 "too early to tell", 
                 "regulatory/political uncertainty")
  
  
#  Figure 3
  
 par(mfrow = c(1, 2) ,mar=c(4,4,1,2)) 
plot.estimateEffect(prep, 
                    main="EU ETS emission level", 
                    ci.level=.90,
                    covariate = "emis2", 
                    topics = topicselect,
                    model=etsPrevFit, 
                    method="difference",
                    cov.value1="high", cov.value2="low",
                    labeltype="custom",
                    custom.labels=topiclabels,
                    xlab="Lower emissions      ...      Difference in topic prevalence      ...      Higher emissions",
                    xlim=c(-.15, .15))

plot.estimateEffect(prep, 
                    main="ETS vs. non-ETS respondents", 
                    ci.level=.90,
                    covariate = "ETS", 
                    model=etsPrevFit, 
                    method="difference",
                    cov.value1=1, cov.value2=0,
                    topics = topicselect,
                    labeltype="custom",
                    custom.labels=topiclabels,
                    xlim=c(-.06,.06),
                    xlab="Non-ETS     ...     Difference in topic prevalence     ...     ETS compliance")

 par(mfrow = c(1, 1) ,mar=c(4,4,1,2)) 

# Figure 4

# Year, 2 selected:
plot.estimateEffect(prep, 
                    ci.level=.90,
                    covariate = "year", 
                    model=etsPrevFit, 
                    method="continuous",
                    topics = topicselect[c(1,4)],
                    labeltype="custom",
                    custom.labels=topiclabels[c(1,4)],
                    xlab="")

