************************************************************
* "Who Opposes Climate Regulation? Business Preferences 
* for the European Emission Trading Scheme"
* Federica Genovese & Endre Tvinnereim
* 02.05.18 (Run on Stata 13 by FG)
************************************************************

use "/Users/genovesefederica/Dropbox/ETS_opinionconsultation/rep_GenoveseTvinnereim_rio/Data/ets_20082013aggregate.dta", clear
*cd O:\2.3.ETS-preferences\data
*use "ets_20082013aggregate.dta", clear

gen id = _n
order id NAMES_STD year sector_new

sort country_id year

drop if EUETScountries!=1
drop if year<2009
drop location

***************************************************
* Variables creation and descriptives in Table A.1
***************************************************

* Response Item 1: Cost efficient
tab  ets_costeff year
tab  ets_costeff year, nolab
gen costeff = (ets_costeff-1)/4
replace costeff=. if ets_costeff==6
tab costeff ets_costeff, mi lab

gen costeff_dummy=1 if costeff==.75 | costeff==1
replace costeff_dummy=0 if costeff<=.6 /* unknowns */
tab costeff costeff_dummy, mi 
tab costeff_dummy,  matcell(freq) matrow(names)
tab costeff_dummy, mi matcell(freq) matrow(names) /* Table A.1*/

gen costeff_ord=1 if costeff_dummy==0
replace costeff_ord=2 if costeff_dummy==1
replace costeff_ord=0 if ets_costeff==6 /* unknowns */
recode ets_costeff (1=1) (2=2) (3=3) (4=4) (5=5) (6=.), gen(original_costeff) 

* Response Item 2: Mature
tab  ets_mat year
tab  ets_mat year, nolab
gen mature = (ets_mat-1)/4
replace mature=. if ets_mat==6 /* unknowns */
tab mature ets_mat, mi lab

gen mature_dummy=1 if mature==.75 | mature==1
replace mature_dummy=0 if mature<=.6 
tab mature mature_dummy, mi lab
tab mature_dummy,  matcell(freq) matrow(names)
tab mature_dummy, mi matcell(freq) matrow(names) /* Table A.1*/

gen mature_ord=1 if mature_dummy==0
replace mature_ord=2 if mature_dummy==1
replace mature_ord=0 if ets_mat==6 /* unknowns */
recode mature (1=1) (2=2) (3=3) (4=4) (5=5) (6=.), gen(original_mature) 

* Response Item 3: Reduce
tab  ets_reduce year
tab  ets_reduce year, nolab
recode ets_reduce (1=1) (2 3=0) (4=.) (5=.), gen(reduced)
tab reduced ets_reduce, mi lab
tab reduced,  matcell(freq) matrow(names)
tab reduced, mi matcell(freq) matrow(names) /* Table A.1*/

gen reduced_ord=1 if reduced==0
replace reduced_ord=2 if reduced==1
replace reduced_ord=0 if ets_mat==4 | ets_mat==5  /* unknowns */
recode ets_reduce (1=3) (2=2) (3=1) (4=.) (5=.), gen(original_reduce) 

* Response Item 4: Salience of Co2 price
tab carpri_lterm year
tab carpri_lterm year, nolab
recode carpri_lterm (1 2=0) (3=1) (4=.), gen(salco2price)
tab salco2price carpri_lterm, mi lab
tab salco2price,  matcell(freq) matrow(names)
tab salco2price, mi matcell(freq) matrow(names) /* Table A.1*/

gen salco2price_ord=1 if salco2price==0
replace salco2price_ord=2 if salco2price==1
replace salco2price_ord=0 if carpri_lterm==4  /* unknowns */
recode carpri_lterm (1=1) (2=2) (3=3) (4=.), gen(original_carpri)  

* Response Item 5: Considering moving abroad because of ETS
tab prod_reloc year
tab prod_reloc year, nolab
recode prod_reloc (1 2 3=1) (4=0) (5=.), gen(move)
tab move prod_reloc, mi lab
tab move,  matcell(freq) matrow(names)
tab move, mi matcell(freq) matrow(names) /* Table A.1*/

gen move_ord=1 if move==0
replace move_ord=2 if move==1
replace move_ord=0 if prod_reloc==5  /* unknowns */
recode prod_reloc (4=1) (3=2) (2=3) (1=4) (5=.), gen(original_move)

/*
Emissions: Level of your company's emissions 
1	Less than 500,000 tonnes : lowcost
2	500,000 - 1 million tonnes : lowcost
3	1 million - 5 million tonnes: highcost
4	5 million - 10 million tonnes: highcost
5	More than 10 million tonnes: highcost
6	No emissions (Government and NGO sector)
7	Don't know
*/

* Firm CO2
tab emissions year
tab emissions year, nolab
gen firm_co2=emissions
replace firm_co2=. if emissions==6 | emissions==7  /* govt/ngo and unknowns */
gen firm_highco2 =. 
replace firm_highco2=0 if emissions==1 | emissions==2 
replace firm_highco2=1 if  emissions==3 |  emissions==4 |  emissions==5
tab firm_highco2 sector_new , mi lab
tab firm_highco2,  matcell(freq) matrow(names)
tab firm_highco2, mi matcell(freq) matrow(names) /* Table A.1*/

gen emissions_ord=1 if firm_highco2==0
replace emissions_ord=2 if firm_highco2==1
replace emissions_ord=0 if emissions==6 | emissions==7  /* unknowns */

* Sector CO2
tab  sector_mtco2_dummy
tab sector_mtco2_dummy,  matcell(freq) matrow(names)
tab sector_mtco2_dummy, mi matcell(freq) matrow(names)  /* Table A.1*/

*************************
* Table 1: Descriptives
*************************
 
tab emissions if sector_new!=. & firm_highco2!=. /* Table 1, top of second column */

* Our data covers in total (116*10)+(47*5)+(152*1)+(74*0.5)+(224*0)=1584 millions tons of GHG [based on self-declared "emissions" and tabbing emissions if emissions!=6 &  emissions!=7]

tab sector_new  if sector_new!=. & firm_highco2!=. /* Table 1, bottom of second column */

* Comparison EU ETS (see manuscript details for ref of data source) and our sample
* Power -  Our dataset: 39.8%
* Manufacturing (pulp and paper, metals) and construction (cement lime ad glass) - Our dataset: 7.34+5.87+15.66 =28.87%
* Food (included in Manufacturing) - Our dataset (food): 0.98%
* Mining (oil and gas and transport) -  Our dataset: 14.1%
* Industrial processes (chemicals) - Our dataset: 2.8%
* Aviation and Maritime Transport (see Bunkers) - Our dataset: 0.99%
* Other (including Waste) - Our dataset: 12.5%

/*
Sectors: mtco2
	Public Power & Heat: powerhear
	Metals and Oil & Gas: mining
	Pulp & Paper, Cement, Lime and Glass, Chemicals: manu
	Aviation: aviation (bunkers)  
	
Sectors: ulc (unit labour cost)
	Public Power & Heat, Metals and Oil & Gas => OECD/IEA ISIC BDE (Mining and Utilities) 
	Pulp and Paper, Cement, Lime and Glass, Chemicals => OECD/IEA ISIC C (Manufacturing) 
	Aviation & Food => Retail trade, food services, transport and storage  
	Other
*/

************************************************
* Figure 1: variation of responses across time
************************************************

gen firm_highco2new = firm_highco2
label define firm_highco2new 0 "Low CO2" 1 "High CO2"
lab value firm_highco2new firm_highco2new

egen average_ets_costeff = mean(ets_costeff), by(year)
egen average_ets_mat = mean(ets_mat), by(year)
egen average_ets_reduce = mean(ets_reduce), by(year)
egen average_carpri_lterm = mean(carpri_lterm), by(year)
egen average_prod_reloc = mean(prod_reloc), by(year)

egen averfirm_ets_costeff = mean(ets_costeff), by(year firm_highco2new)
egen averfirm_ets_mat = mean(ets_mat), by(year firm_highco2new)
egen averfirm_ets_reduce = mean(ets_reduce), by(year firm_highco2new)
egen averfirm_carpri_lterm = mean(carpri_lterm), by(year firm_highco2new)
egen averfirm_prod_reloc = mean(prod_reloc), by(year firm_highco2new)

/*using plottig for better visualization*/
*ssc install blindschemes
set scheme plottig

#delimit ;
twoway (line average_ets_costeff year, sort lpattern("-.-") lcol(cranberry) lwidth(medthick medthick))  (line average_ets_mat year, sort lpattern("._.") lcol(eltblue) lwidth(medthick medthick)) (line average_ets_reduce year, sort lpattern(--_) lcol(green) lwidth(medthick medthick))
 (line average_carpri_lterm year, sort lpattern(shortdash) lcol(navy) lwidth(medthick medthick)) (line average_prod_reloc year, sort lpattern(dot) lcol(pink) lwidth(medthick medthick)),   
ylab(2(.5)4)
ytitle("Response Scale")
legend(label(1 "ETS Cost Efficiency") label(2 "ETS Maturity") label(3 "CO2 Reduction") label(4 "Saliency of CO2 Price for Investment") label(5 "Considering Relocation"))
legend(cols(1) size(small) symysize(3) span ) legend(region(lwidth(none))) ;
#delimit cr

**************************************************************************
* Figure 2: Variation of responses across time by high/low emission firms
**************************************************************************

*cost efficiency
#delimit ;
twoway (line averfirm_ets_costeff year, sort lpattern(dash) lcol(cranberry) lwidth(medthick medthick)),   by(firm_highco2new,  row(1) note(" ") title("Cost Efficiency"))   
ytitle("Cost Efficiency")
ylab(3(.25)3.5)
legend(cols(1) size(small) symysize(3) span ) legend(region(lwidth(none))) ;
#delimit cr

*maturity
#delimit ;
twoway (line averfirm_ets_mat year, sort lpattern(dash) lcol(eltblue) lwidth(medthick medthick)),   by(firm_highco2new,  row(1) note(" ") title("Maturity"))   
ytitle("Maturity")
ylab(2.5(.5)3.5)
legend(cols(1) size(small) symysize(3) span ) legend(region(lwidth(none))) ;
#delimit cr

* CO2 reduction 
#delimit ;
twoway (line averfirm_ets_reduce year, sort lpattern(dash) lcol(green) lwidth(medthick medthick)),   by(firm_highco2new,  row(1) note(" ") title("CO2 Reduction"))   
ytitle("CO2 Reduction")
ylab(1.5(.5)2.75)
legend(cols(1) size(small) symysize(3) span ) legend(region(lwidth(none))) ;
#delimit cr

*LT price saliency
#delimit ;
twoway (line averfirm_carpri_lterm year, sort lpattern(dash) lcol(navy) lwidth(medthick medthick)),   by(firm_highco2new,  row(1) note(" ") title("Price Salience"))   
ytitle("Price Salience")
ylab(1.5(.5)2.75)
legend(cols(1) size(small) symysize(3) span ) legend(region(lwidth(none))) ;
#delimit cr

*relocation
#delimit ;
twoway (line averfirm_prod_reloc year, sort lpattern(dash) lcol(pink) lwidth(medthick medthick)),   by(firm_highco2new,  row(1) note(" ") title("Relocation"))   
ytitle("Relocation")
ylab(3.5(.25)4)
legend(cols(1) size(small) symysize(3) span ) legend(region(lwidth(none)));
#delimit cr

************************************************
* Table 2: Principal component scores analysis
************************************************

sum costeff mature reduced salco2price move if sector_new!=. & firm_highco2!=.
pca costeff mature reduced salco2price move if sector_new!=. & firm_highco2!=., factor(2)
predict pc1 pc2, score

***********************************
* Table 3: Main regression results
***********************************

reg pc1 firm_highco2 sector_mtco2_dummy ulc_dummy lgdppc regquality gov_party fossilsupport_rate i.year i.country_id if sector!=., cluster(country_id) 
reg pc1 firm_co2 sector_mtco2 ulc_dummy lgdppc regquality gov_party fossilsupport_rate i.year i.country_id if sector!=., cluster(country_id) 
reg pc2 firm_highco2 sector_mtco2_dummy ulc_dummy lgdppc regquality gov_party fossilsupport_rate i.year i.country_id if sector!=., cluster(country_id) 
reg pc2 firm_co2 sector_mtco2 ulc_dummy lgdppc regquality gov_party fossilsupport_rate i.year i.country_id if sector!=., cluster(country_id) 

**********************************************
* Table 4: Disaggregated Emissions and Sectors
**********************************************

gen sector_foranalysis=sector_new+1
replace sector_foranalysis=1 if sector_foranalysis==5 /* pulp and paper as reference*/

reg pc1 i.emissions sector_mtco2_dummy ulc_dummy lgdppc regquality gov_party fossilsupport_rate i.year i.country_id if sector!=.  & emissions!=6 & emissions!=7, cluster(country_id) 
reg pc1 firm_highco2 i.sector_foranalysis ulc_dummy lgdppc regquality gov_party fossilsupport_rate i.year i.country_id if sector!=., cluster(sector_new) 
reg pc2 i.emissions sector_mtco2_dummy ulc_dummy lgdppc regquality gov_party fossilsupport_rate   i.year i.country_id if sector!=. & emissions!=6 & emissions!=7, cluster(country_id) 
reg pc2 firm_highco2 i.sector_foranalysis ulc_dummy lgdppc regquality gov_party  fossilsupport_rate  i.year i.country_id if sector!=., cluster(sector_new) 

*********************************************
* Table 5: Single individual responses models
*********************************************

probit costeff_dummy firm_highco2 sector_mtco2_dummy ulc_dummy lgdppc  regquality gov_party fossilsupport_rate i.year i.country_id if sector!=., cluster(country_id)
probit mature_dummy firm_highco2 sector_mtco2_dummy ulc_dummy lgdppc regquality gov_party fossilsupport_rate i.year i.country_id if sector!=., cluster(country_id)
probit reduced firm_highco2 sector_mtco2_dummy  ulc_dummy lgdppc regquality gov_party fossilsupport_rate i.year i.country_id if sector!=., cluster(country_id) 
probit salco2price firm_highco2 sector_mtco2_dummy ulc_dummy lgdppc regquality gov_party fossilsupport_rate i.year i.country_id if sector!=., cluster(country_id) 
probit move firm_highco2 sector_mtco2_dummy ulc_dummy lgdppc regquality gov_party fossilsupport_rate i.year i.country_id if sector!=., cluster(country_id) 

************
* Appendix *
************

************************
* Table A.2: Descriptives
************************

gen byte miss1 = missing(ets_costeff)
gen byte miss2 = missing(emissions)
tab miss1 miss2,  chi2
drop miss1 

gen byte miss1 = missing(ets_mat)
tab miss1 miss2,  chi2
drop miss1 

gen byte miss1 = missing(ets_reduce)
tab miss1 miss2,  chi2
drop miss1 

gen byte miss1 = missing(carpri_lterm)
tab miss1 miss2,  chi2
drop miss1 

gen byte miss1 = missing(prod_reloc)
tab miss1 miss2,  chi2
drop miss1 

*************************
* Table A.3: Descriptives
*************************

sum pc1 pc2 firm_co2 firm_highco2 sector_mtco2 sector_mtco2_dummy ulc_dummy lgdppc regquality gov_party fossilsupport_rate if sector_new!=. & firm_highco2!=.

*****************************************************************
* Table A.4: Principal component scores analysis (original scales)
*****************************************************************

pca original_costeff original_mature original_reduce original_carpri original_move if sector_new!=. & firm_highco2!=.,  factor(2)
predict pc_1original pc_2original, score

**********************************************
* Table A.5: Analysis with original scale DVs
**********************************************

reg pc_1original firm_highco2 sector_mtco2_dummy ulc_dummy lgdppc regquality gov_party fossilsupport_rate i.year i.country_id if sector!=., cluster(country_id) 
*reg pc_1original firm_co2 sector_mtco2 ulc_dummy lgdppc regquality gov_party fossilsupport_rate i.year i.country_id if sector!=., cluster(country_id) 
reg pc_2original firm_highco2 sector_mtco2_dummy ulc_dummy lgdppc regquality gov_party fossilsupport_rate i.year i.country_id if sector!=., cluster(country_id) 
*reg pc_2original firm_co2 sector_mtco2 ulc_dummy lgdppc regquality gov_party fossilsupport_rate i.year i.country_id if sector!=., cluster(country_id) 

reg original_costeff firm_highco2 sector_mtco2_dummy ulc_dummy lgdppc regquality gov_party fossilsupport_rate i.year i.country_id if sector!=., cluster(country_id) 
reg original_mature firm_highco2 sector_mtco2_dummy ulc_dummy lgdppc regquality gov_party fossilsupport_rate i.year i.country_id if sector!=., cluster(country_id) 
reg original_reduce firm_highco2 sector_mtco2_dummy ulc_dummy lgdppc regquality gov_party fossilsupport_rate i.year i.country_id if sector!=., cluster(country_id) 
reg original_carpri firm_highco2 sector_mtco2_dummy  ulc_dummy lgdppc regquality gov_party fossilsupport_rate i.year i.country_id if sector!=., cluster(country_id)
reg original_move firm_highco2 sector_mtco2_dummy ulc_dummy lgdppc regquality gov_party fossilsupport_rate i.year i.country_id if sector!=., cluster(country_id)

*********************************************
* Table A.6: Two-Level random effects models
*********************************************
	
xtmixed pc1 firm_highco2 sector_mtco2_dummy ulc_dummy lgdppc regquality gov_party fossilsupport_rate  i.year  ||   country_id: if sector!=. , cov(un)  var
xtmixed pc1 firm_co2 sector_mtco2 ulc_dummy lgdppc regquality gov_party fossilsupport_rate  i.year  ||   country_id:  if sector!=., cov(un)  var 
xtmixed pc2 firm_highco2 sector_mtco2_dummy ulc_dummy lgdppc regquality gov_party fossilsupport_rate  i.year  ||   country_id: if sector!=. , cov(un)   var
xtmixed pc2 firm_co2 sector_mtco2 ulc_dummy lgdppc regquality gov_party fossilsupport_rate  i.year  ||   country_id:  if sector!=., cov(un)  var

*******************************************
* Table A.7: Binary composite score models
*******************************************

egen meanpc1 = mean(pc1), by (country_id)
egen meanpc2 = mean(pc2), by (country_id)
by country_id: gen pcascore1=1 if pc1>meanpc1 & pc1!=.
replace pcascore1=0 if pc1<meanpc1 & pc1!=.
by country_id: gen pcascore2=1 if pc2>meanpc2 & pc2!=.
replace pcascore2=0 if pc2<meanpc2 & pc2!=.

probit pcascore1 firm_highco2 sector_mtco2_dummy ulc_dummy lgdppc regquality gov_party fossilsupport_rate i.year i.country_id if sector!=., cluster(country_id) 
reg pcascore1 firm_highco2 sector_mtco2_dummy ulc_dummy lgdppc regquality gov_party fossilsupport_rate i.year i.country_id if sector!=., cluster(country_id) 
probit pcascore2 firm_highco2 sector_mtco2_dummy ulc_dummy lgdppc regquality gov_party fossilsupport_rate i.year i.country_id if sector!=., cluster(country_id) 
reg pcascore2 firm_highco2 sector_mtco2_dummy ulc_dummy lgdppc regquality gov_party fossilsupport_rate i.year i.country_id if sector!=., cluster(country_id) 

**************************************************************
* Table A.8: Single individual responses models (linear models)
**************************************************************

reg costeff firm_highco2 sector_mtco2_dummy ulc_dummy lgdppc regquality gov_party fossilsupport_rate i.year i.country_id if sector!=., cluster(country_id) 
reg mature firm_highco2 sector_mtco2_dummy ulc_dummy lgdppc regquality gov_party fossilsupport_rate i.year i.country_id if sector!=., cluster(country_id) 
reg reduced firm_highco2 sector_mtco2_dummy ulc_dummy lgdppc regquality gov_party fossilsupport_rate i.year i.country_id if sector!=., cluster(country_id) 
reg salco2price firm_highco2 sector_mtco2_dummy  ulc_dummy lgdppc regquality gov_party fossilsupport_rate i.year i.country_id if sector!=., cluster(country_id)
reg move firm_highco2 sector_mtco2_dummy ulc_dummy lgdppc regquality gov_party fossilsupport_rate i.year i.country_id if sector!=., cluster(country_id)

***************************************************************
* Table A.9: Single individual responses models (continuous Co2)
***************************************************************

probit costeff_dummy firm_co2 sector_mtco2 ulc_dummy lgdppc  regquality gov_party fossilsupport_rate i.year i.country_id if sector!=., cluster(country_id) 
probit mature_dummy firm_co2 sector_mtco2 ulc_dummy lgdppc  regquality gov_party fossilsupport_rate i.year i.country_id if sector!=., cluster(country_id) 
probit reduced firm_co2 sector_mtco2  ulc_dummy lgdppc regquality gov_party fossilsupport_rate i.year i.country_id if sector!=., cluster(country_id) 
probit salco2price firm_co2 sector_mtco2  ulc_dummy lgdppc regquality gov_party fossilsupport_rate i.year i.country_id if sector!=., cluster(country_id) 
probit move firm_co2 sector_mtco2  ulc_dummy lgdppc regquality gov_party fossilsupport_rate i.year i.country_id if sector!=., cluster(country_id) 
	
******************************************************************************************
* Table A.10: Variation across time - 2010 (cheap credits) vs 2013 (1st year of auctioning)
*******************************************************************************************

reg pc1 firm_highco2 sector_mtco2_dummy  i.country_id if sector!=. & year==2010, cluster(country_id) 	
reg pc1 firm_co2 sector_mtco2  i.country_id if sector!=. & year==2010, cluster(country_id) 
reg pc2 firm_highco2 sector_mtco2_dummy  i.country_id if sector!=. & year==2010, cluster(country_id) 	
reg pc2 firm_co2 sector_mtco2  i.country_id if sector!=. & year==2010, cluster(country_id) 	

reg pc1 firm_highco2 sector_mtco2_dummy  i.country_id if sector!=. & year==2013, cluster(country_id) 
reg pc1 firm_co2 sector_mtco2  i.country_id if sector!=. & year==2013, cluster(country_id) 	
reg pc2 firm_highco2 sector_mtco2_dummy  i.country_id if sector!=. & year==2013, cluster(country_id)
reg pc2 firm_co2 sector_mtco2  i.country_id if sector!=. & year==2013, cluster(country_id)
	
***********************************************************
* Table A.11: Firm Co2 X Year 2013 (1st year of auctioning)
***********************************************************

gen year2013=.
replace year2013=1 if year==2013
replace year2013=0 if year!=2013

reg costeff_dummy firm_co2##year2013 sector_mtco2_dummy i.country_id if sector!=., cluster(country_id) 
reg mature_dummy firm_co2##year2013 sector_mtco2_dummy i.country_id if sector!=., cluster(country_id) 
reg reduced firm_co2##year2013 sector_mtco2_dummy  i.country_id if sector!=., cluster(country_id) 
reg salco2price firm_co2##year2013 sector_mtco2_dummy i.country_id if sector!=., cluster(country_id) 
reg move firm_co2##year2013 sector_mtco2_dummy  i.country_id if sector!=., cluster(country_id) 

************************************************************ 
* Table A.15: Factor analysis without "relocation" question
************************************************************

pca costeff mature reduced salco2price if sector_new!=. & firm_highco2!=., factor(2)
predict pc_orel1 pc_orel2, score

************************************************************ 
* Table A.16: Models of scores without "relocation" question
************************************************************

reg pc_orel1 firm_highco2 sector_mtco2_dummy ulc_dummy lgdppc regquality gov_party fossilsupport_rate i.year i.country_id if sector!=., cluster(country_id) 
reg pc_orel1 firm_co2 sector_mtco2 ulc_dummy lgdppc regquality gov_party fossilsupport_rate i.year i.country_id if sector!=., cluster(country_id) 
reg pc_orel2 firm_highco2 sector_mtco2_dummy ulc_dummy lgdppc regquality gov_party fossilsupport_rate i.year i.country_id if sector!=., cluster(country_id) 
reg pc_orel2 firm_co2 sector_mtco2 ulc_dummy lgdppc regquality gov_party fossilsupport_rate i.year i.country_id if sector!=., cluster(country_id) 

************************************************** 
* Table A.17: SectorGHG*FirmGHG Interaction models
**************************************************

reg pc1 firm_highco2##sector_mtco2_dummy ulc_dummy lgdppc regquality gov_party fossilsupport_rate i.year i.country_id if sector!=., cluster(country_id) 
reg pc2 firm_highco2##sector_mtco2_dummy ulc_dummy lgdppc regquality gov_party fossilsupport_rate i.year i.country_id if sector!=., cluster(country_id) 

reg costeff_dummy firm_highco2##sector_mtco2_dummy ulc_dummy lgdppc regquality gov_party fossilsupport_rate i.year i.country_id if sector!=., cluster(country_id) 
reg mature_dummy firm_highco2##sector_mtco2_dummy ulc_dummy lgdppc regquality gov_party fossilsupport_rate i.year i.country_id if sector!=., cluster(country_id) 
reg reduced firm_highco2##sector_mtco2_dummy ulc_dummy lgdppc regquality gov_party fossilsupport_rate i.year i.country_id if sector!=., cluster(country_id)
reg salco2price firm_highco2##sector_mtco2_dummy ulc_dummy lgdppc regquality gov_party fossilsupport_rate i.year i.country_id if sector!=., cluster(country_id) 
reg move firm_highco2##sector_mtco2_dummy ulc_dummy lgdppc regquality gov_party fossilsupport_rate i.year i.country_id if sector!=., cluster(country_id) 
	

***********************************************************************************
* 2010 individual-level data: Controlling for age & education (only asked in 2010)
***********************************************************************************	

use "/Users/genovesefederica/Dropbox/ETS_opinionconsultation/rep_GenoveseTvinnereim_rio/Data/ets_2010.dta", clear

* Q2_1: cost effective
* Q2_2: maturity
* Q16: reduction
* Q20: saliency CO2 price
* Q21: relocation
* country (Q52): original country variable
* sector (Q6): original sector variable
* age_group(Q53): original age variable
* edu_degree (Q54): original education level, high school -> doctorate
* emissions (Q56): original firms' emission variable
* sector_mtco2: added 2010 sectoral data (see source in main text)

replace Q2_1=. if Q2_1==-111
gen costeff = (Q2_1-1)/4
replace costeff=. if Q2_1==6  /* unknowns */
gen costeff_dummy=1 if costeff==.75 | costeff==1
replace costeff_dummy=0 if costeff<=.6

replace Q2_2=. if Q2_2==-111
gen mature = (Q2_2-1)/4
replace mature=. if Q2_2==6 /* unknowns */
gen mature_dummy=1 if mature==.75 | mature==1
replace mature_dummy=0 if mature<=.6 

replace Q16=. if Q16==-111
recode Q16 (1=1) (2 3=0) (4=.) (5=.), gen(reduced)

replace Q20=. if Q20==-111
recode Q20 (1 2=0) (3=1) (4=.), gen(salco2price)

replace Q21=. if Q21==-111
recode Q21 (1 2 3=1) (4=0) (5=.), gen(move)

sum costeff mature reduced salco2price move

replace emissions=. if  emissions==-111 | emissions==7 /* unknowns */
gen firm_co2=emissions
replace firm_co2=. if emissions==6  /* 1 govt/ngo  */
gen firm_highco2 =. 
replace firm_highco2=0 if emissions==1 | emissions==2 
replace firm_highco2=1 if  emissions==3 |  emissions==4 |  emissions==5

replace age_group=. if age_group==-111
replace edu_degree=. if edu_degree==-111 | edu_degree==6

sort country
by country: egen sector_mtco2_dummy = xtile(sector_mtco2), nquantiles(2)

*********************************************************************************
* Table A.12 (top panel): Age & education across people of high- and low-CO2 firms 
*********************************************************************************

tab  age_group firm_highco2, matcell(freq) matrow(names)
tab  edu_degree firm_highco2, matcell(freq) matrow(names)

*************************************************************
* Table A.13: Basic models controlling for age and education
*************************************************************

pca costeff mature reduced salco2price move if firm_highco2!=., factor(2)
predict pc1 pc2, score

reg pc1 firm_highco2 sector_mtco2_dummy i.age_group i.edu_degree i.country , cluster(country) 
reg pc2 firm_highco2 sector_mtco2_dummy i.age_group i.edu_degree i.country, cluster(country) 

reg costeff firm_highco2 sector_mtco2_dummy i.age_group i.edu_degree i.country , cluster(country) 
reg mature firm_highco2 sector_mtco2_dummy i.age_group i.edu_degree i.country , cluster(country)
reg reduced firm_highco2 sector_mtco2_dummy i.age_group i.edu_degree  i.country , cluster(country) 
reg salco2price firm_highco2 sector_mtco2_dummy i.age_group i.edu_degree i.country  , cluster(country) 
reg move firm_highco2 sector_mtco2_dummy i.age_group i.edu_degree i.country , cluster(country)

**************************************************************************
* 2010 aggregate-level data: Controlling for firms' employee size & revenue
**************************************************************************	

use "/Users/genovesefederica/Dropbox/ETS_opinionconsultation/rep_GenoveseTvinnereim_rio/Data/ets_2010aggregate_emprev.dta", clear

gen emplog=log(employees)
gen revlog=log(revenue)
egen emp_binary = xtile(emplog), nquantiles(2)
egen rev_binary = xtile(revlog), nquantiles(2)

* Cost efficient
gen costeff = (ets_costeff-1)/4
replace costeff=. if ets_costeff==6
tab costeff ets_costeff, mi lab
gen costeff_dummy=1 if costeff==.75 | costeff==1
replace costeff_dummy=0 if costeff<=.6 /* unknowns */

* Mature
tab  ets_mat year
tab  ets_mat year, nolab
gen mature = (ets_mat-1)/4
replace mature=. if ets_mat==6 /* unknowns */
tab mature ets_mat, mi lab
gen mature_dummy=1 if mature==.75 | mature==1
replace mature_dummy=0 if mature<=.6 

* Reduce
tab  ets_reduce year
tab  ets_reduce year, nolab
recode ets_reduce (1=1) (2 3=0) (4=.) (5=.), gen(reduced)

* Salience of Co2 price
tab carpri_lterm year
tab carpri_lterm year, nolab
recode carpri_lterm (1 2=0) (3=1) (4=.), gen(salco2price)

* Considering moving abroad because of ETS
tab prod_reloc year
tab prod_reloc year, nolab
recode prod_reloc (1 2 3=1) (4=0) (5=.), gen(move)

* Emissions
gen firm_co2=emissions
replace firm_co2=. if emissions==6 | emissions==7  /* govt/ngo and unknowns */
gen firm_highco2 =. 
replace firm_highco2=0 if emissions==1 | emissions==2 
replace firm_highco2=1 if  emissions==3 |  emissions==4 |  emissions==5

************************************************************************************
* Table A.12 (bottom panel): Size & revenue across people of high- and low-CO2 firms 
************************************************************************************
tab emp_binary firm_highco2, matcell(freq) matrow(names)
tab rev_binary firm_highco2, matcell(freq) matrow(names)

****************************************************************
* Table A.14: Basic models controlling for firms' size & revenue
****************************************************************

pca costeff mature reduced salco2price move if firm_highco2!=., factor(2)
predict pc1 pc2, score

reg pc1  firm_highco2 sector_mtco2_dummy emplog revlog i.country_id if sector!=. , cluster(country) 
reg pc2 firm_highco2 sector_mtco2_dummy emplog revlog i.country_id if sector!=., cluster(country) 

reg costeff firm_highco2 sector_mtco2_dummy emplog revlog i.country_id if sector!=., cluster(country) 
reg mature firm_highco2 sector_mtco2_dummy emplog revlog i.country_id if sector!=., cluster(country)
reg reduced firm_highco2 sector_mtco2_dummy emplog revlog  i.country_id if sector!=., cluster(country) 
reg salco2price firm_highco2 sector_mtco2_dummy emplog revlog i.country_id if sector!=., cluster(country) 
reg move firm_highco2 sector_mtco2_dummy emplog revlog i.country_id if sector!=. , cluster(country)
	



